@@ -2,7 +2,6 @@
 /* Icinga Web 2 Top Level View | (c) 2017 Icinga Development Team | GPLv2+ */
 
 use Icinga\Module\Toplevelview\Tree\TLVStatus;
-use Icinga\Web\Url;
 
 class Zend_View_Helper_Badges extends Zend_View_Helper_Abstract
 {
@@ -18,6 +17,10 @@ class Zend_View_Helper_Badges extends Zend_View_Helper_Abstract
         return trim($s);
     }
 
+    /**
+     * badges renders a TLVNode's TLVStatus into HTML.
+     * A badge represents the number of status of a given node
+     */
     public function badges(TLVStatus $status, $problemsOnly = true, $showTotal = false)
     {
         $htm = '';
