@@ -2,6 +2,7 @@
 /* Icinga Web 2 | (c) 2016 Icinga Development Team | GPLv2+ */
 
 use Icinga\Module\Toplevelview\Tree\TLVTreeNode;
+use Icinga\Module\Toplevelview\Util\Str;
 
 class Zend_View_Helper_Breadcrumb extends Zend_View_Helper_Abstract
 {
@@ -9,6 +10,8 @@ class Zend_View_Helper_Breadcrumb extends Zend_View_Helper_Abstract
     public $view;
 
     /**
+     * breadcrumb renders a list of TLVTreeNodes into a HTML breadcrumb list
+     *
      * @param TLVTreeNode[] $breadcrumb
      *
      * @return string
@@ -18,7 +21,7 @@ class Zend_View_Helper_Breadcrumb extends Zend_View_Helper_Abstract
         $htm = '<ul class="breadcrumb">';
         foreach ($breadcrumb as $crumb) {
             $htm .= '<li>' . $this->view->qlink(
-                $crumb->getTitle(),
+                Str::limit($crumb->getTitle()),
                 'toplevelview/show/tree',
                 array(
                         'name' => $config_name,
